@@ -4,7 +4,7 @@
 # Tests for the `humanfriendly' package.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: January 17, 2017
+# Last Change: May 4, 2017
 # URL: https://humanfriendly.readthedocs.io
 
 """Test suite for the `humanfriendly` package."""
@@ -51,6 +51,7 @@ from humanfriendly.terminal import (
     clean_terminal_output,
     connected_to_terminal,
     find_terminal_size,
+    get_pager_command,
     show_pager,
     terminal_supports_colors,
 )
@@ -167,6 +168,8 @@ class HumanFriendlyTestCase(unittest.TestCase):
         self.assertEqual(5, humanfriendly.parse_timespan('5 seconds'))
         self.assertEqual(60 * 2, humanfriendly.parse_timespan('2m'))
         self.assertEqual(60 * 2, humanfriendly.parse_timespan('2 minutes'))
+        self.assertEqual(60 * 3, humanfriendly.parse_timespan('3 min'))
+        self.assertEqual(60 * 3, humanfriendly.parse_timespan('3 mins'))
         self.assertEqual(60 * 60 * 3, humanfriendly.parse_timespan('3 h'))
         self.assertEqual(60 * 60 * 3, humanfriendly.parse_timespan('3 hours'))
         self.assertEqual(60 * 60 * 24 * 4, humanfriendly.parse_timespan('4d'))
@@ -662,9 +665,21 @@ class HumanFriendlyTestCase(unittest.TestCase):
             sys.stdout = saved_stdout
             sys.stderr = saved_stderr
 
-    def test_connected_to_terminal(self):
-        """Test :func:`humanfriendly.terminal.connected_to_terminal()`."""
-        self.check_terminal_capabilities(connected_to_terminal)
+    def test_terminal_capabilities(self):
+        """Test the functions that check for terminal capabilities."""
+        for test_stream in connected_to_terminal, terminal_supports_colors:
+            # This test suite should be able to run interactively as well as
+            # non-interactively, so we can't expect or demand that standard streams
+            # will always be connected to a terminal. Fortunately Capturer enables
+            # us to fake it :-).
+            for stream in sys.stdout, sys.stderr:
+                with CaptureOutput():
+                    assert test_stream(stream)
+            # Test something that we know can never be a terminal.
+            with open(os.devnull) as handle:
+                assert not test_stream(handle)
+            # Verify that objects without isatty() don't raise an exception.
+            assert not test_stream(object())
 
     def test_show_pager(self):
         """Test :func:`humanfriendly.terminal.show_pager()`."""
@@ -688,24 +703,33 @@ class HumanFriendlyTestCase(unittest.TestCase):
                 # Clear the custom $PAGER value.
                 os.environ.pop('PAGER')
 
-    def test_terminal_supports_colors(self):
-        """Test :func:`humanfriendly.terminal.terminal_supports_colors()`."""
-        self.check_terminal_capabilities(terminal_supports_colors)
-
-    def check_terminal_capabilities(self, test_stream):
-        """Helper for :func:`test_connected_to_terminal()` and func:`test_terminal_supports_colors()`."""
-        # This test suite should be able to run interactively as well as
-        # non-interactively, so we can't expect or demand that standard streams
-        # will always be connected to a terminal. Fortunately Capturer enables
-        # us to fake it :-).
-        for stream in sys.stdout, sys.stderr:
-            with CaptureOutput():
-                assert test_stream(stream)
-        # Test something that we know can never be a terminal.
-        with open(os.devnull) as handle:
-            assert not test_stream(handle)
-        # Verify that objects without isatty() don't raise an exception.
-        assert not test_stream(object())
+    def test_get_pager_command(self):
+        """Test :func:`humanfriendly.terminal.get_pager_command()`."""
+        # Make sure --RAW-CONTROL-CHARS isn't used when it's not needed.
+        assert '--RAW-CONTROL-CHARS' not in get_pager_command("Usage message")
+        # Make sure --RAW-CONTROL-CHARS is used when it's needed.
+        assert '--RAW-CONTROL-CHARS' in get_pager_command(ansi_wrap("Usage message", bold=True))
+        # Make sure that less-specific options are only used when valid.
+        options_specific_to_less = ['--no-init', '--quit-if-one-screen']
+        for pager in 'cat', 'less':
+            original_pager = os.environ.get('PAGER', None)
+            try:
+                # Set $PAGER to `cat' or `less'.
+                os.environ['PAGER'] = pager
+                # Get the pager command line.
+                command_line = get_pager_command()
+                # Check for less-specific options.
+                if pager == 'less':
+                    assert all(opt in command_line for opt in options_specific_to_less)
+                else:
+                    assert not any(opt in command_line for opt in options_specific_to_less)
+            finally:
+                if original_pager is not None:
+                    # Restore the original $PAGER value.
+                    os.environ['PAGER'] = original_pager
+                else:
+                    # Clear the custom $PAGER value.
+                    os.environ.pop('PAGER')
 
     def test_find_meta_variables(self):
         """Test :func:`humanfriendly.usage.find_meta_variables()`."""
@@ -908,7 +932,7 @@ class HumanFriendlyTestCase(unittest.TestCase):
 
 
 def main(*args, **kw):
-    """Utility function to test the command line interface without invoking a subprocess."""
+    """Test the command line interface without invoking a subprocess."""
     returncode = 0
     input_buffer = StringIO(kw.get('input', ''))
     output_buffer = StringIO()
@@ -931,7 +955,7 @@ def main(*args, **kw):
 
 def normalize_timestamp(value, ndigits=1):
     """
-    Utility function to round timestamps to the given number of digits.
+    Round timestamps to the given number of digits.
 
     This helps to make the test suite less sensitive to timing issues caused by
     multitasking, processor scheduling, etc.
